import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs';
import * as models from '../models/index';
import { BaseService } from '../base/index';
import { RestPythonService } from '../rest-python/rest-python.module';
import { RedhawkService } from '../redhawk/redhawk.module';
import { IWaveformLaunchCommandResponse } from '../waveform/waveform.module';
import { OdmListenerService } from '../sockets/sockets.module';
/**
 * The Domain Service provides access to the Domain model and other interfaces
 * at the REST server including a socket to the ODM Event Channel for monitoring
 * changes to the Domain (applications coming and going, etc.).
 */
export declare class DomainService extends BaseService<models.Domain> {
    protected http: HttpClient;
    protected restPython: RestPythonService;
    protected redhawkService: RedhawkService;
    protected odmListener: OdmListenerService;
    /**
     * Constructor
     * @param http The HTTP service for server callbacks
     * @param restPython The REST Python service for URL serialization
     * @param redhawkService The REDHAWK service that can contains this Domain
     * @param [odmListener] The ODM Listener Service for tracking Domain events
     */
    constructor(http: HttpClient, restPython: RestPythonService, redhawkService: RedhawkService, odmListener: OdmListenerService);
    /**
     * Internal, sets up the base URL
     * @param url Sets the base URL for this service
     */
    setBaseUrl(url: string): void;
    /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     */
    uniqueQuery$(): Observable<models.Domain>;
    /**
     * Configures the domain's properties properties
     * @param properties The list of properties to configure
     */
    configure(properties: models.PropertySet): void;
    /**
     * Get a list of running apps or a specific instance
     * @param [waveformId] The ID of the waveform model to get.  If none provided, a list is returned.
     * @returns Observable Waveform or ResourceRefs
     */
    apps$(waveformId?: string): Observable<models.Waveform> | Observable<models.ResourceRefs>;
    /**
     * Get a list of launchable waveforms
     * Note: this is also on the [Domain's model]{@link Domain#waveforms}
     * @returns Observable WaveformSADRefs
     */
    catalogSads$(): Observable<models.WaveformSADRefs>;
    /**
     * Launch a waveform
     * @param waveformName The [name]{@link WaveformSAD#name} of the Waveform
     * @param [started] Whether or not to also start (or not) the waveform (default stopped).
     * @returns Obsevable IWaveformLaunchCommandResponse
     */
    launch$(waveformName: string, started?: boolean): Observable<IWaveformLaunchCommandResponse>;
    /**
     * Get a list of device managers or a specific instance
     * @param [deviceManagerId] The device manager model to retrieve.  If none provided, returns a listing.
     * @returns Observable DeviceManager or DeviceManagerRefs
     */
    devMgrs$(deviceManagerId?: string): Observable<models.DeviceManager> | Observable<models.DeviceManagerRefs>;
    /**
     * Get a device model or a listing of available devices
     * @param deviceManagerId The device manager's ID containing the Device(s)
     * @param [deviceId] The device ID to retrieve.  If none, a listing is returned.
     * @returns Observable Device or ResourceRefs
     */
    devices$(deviceManagerId: string, deviceId?: string): Observable<models.Device> | Observable<models.ResourceRefs>;
    /** Common 'reconfigure' method to reconnect to the ODM listener when the uniqueID changes. */
    protected reconfigure(id: string, force?: boolean): void;
}
