import { Subscription } from 'rxjs';
import { BulkioPacket } from '../../models/index';
import { PortRef } from './port.ref';
import { RestPythonService } from '../../rest-python/rest-python.module';
/**
 * The PortReceiver interface receives BulkioPacket pushes from
 * the bulkio port service.
 */
export interface PortReceiver {
    /** Callback for when a packet is received on the socket */
    (packet: BulkioPacket): void;
}
/**
 * BulkioRef is akin to the internal "ref" member found in the Python Shell.
 */
export declare class BulkioRef extends PortRef {
    url: string;
    /** The connection (or allocation) ID for the stream */
    private connectionId;
    /** The socket service for this port ref. */
    private bulkioService;
    /**
     * Connect to the packet stream of the bulkio service listener
     * @param {PortReceiver} target - The callback for when new packets are received.
     * @param {string} connection_id - The connection_id (stream_id), if applicable.
     * @return {Subscription} The RxJS Subscription for this connection.
     */
    connectPort(target: PortReceiver, connection_id?: string): Subscription;
    /**
     * Disconnect this connection.
     * NOTE: This is equivalent call unsubscribe() on the Subscription and
     *       also disconnects the service from the server.
     * @param {Subscription} connection - The connection (subscription) returned
     *     from the connectPort call.
     */
    disconnectPort(connection?: Subscription): void;
    /**
     * Set the max number of samples for the X axis (causes inter-sample
     * averaging).  The REST Python server will try to adjust to near this limit
     * based on the data size. Setting the width to less than or equal to 0 will
     * disable this feature.
     * @param {number} value
     */
    xMax: number;
    /**
     * Set the beginning index of the zoom region for the X axis. The index is
     * inclusive and based on data available at the UI (the server will adjust
     * the index for the actual packet size). The zoom will not be enabled until
     * the zoom level is set.
     * @param {number} value
     */
    xBegin: number;
    /**
     * Set the ending index of the zoom region for the X axis. The index is
     * inclusive and based on data available at the UI (the server will adjust
     * the index for the actual packet size). The zoom will not be enabled until
     * the zoom level is set.
     * @param {number} value
     */
    xEnd: number;
    /**
     * Command a zoom in on the X axis. Command will be executed
     * regardless of the value set.
     * @param {number} value
     */
    xZoomIn: number;
    /**
     * Command a zoom reset on the X axis. Command will be executed
     * regardless of the value set.
     * @param {number} value
     */
    xZoomReset: number;
    /**
     * Set the max number of samples for the Y axis (causes inter-sample
     * averaging).  The REST Python server will try to adjust to near this limit
     * based on the data size. Setting the width to less than or equal to 0 will
     * disable this feature.
     * @param {number} value
     */
    yMax: number;
    /**
     * Set the beginning index of the zoom region for the Y axis. The index is
     * inclusive and based on data available at the UI (the server will adjust
     * the index for the actual packet size). The zoom will not be enabled until
     * the zoom level is set.
     * @param {number} value
     */
    yBegin: number;
    /**
     * Set the ending index of the zoom region for the Y axis. The index is
     * inclusive and based on data available at the UI (the server will adjust
     * the index for the actual packet size). The zoom will not be enabled until
     * the zoom level is set.
     * @param {number} value
     */
    yEnd: number;
    /**
     * Command a zoom in on the Y axis. Command will be executed
     * regardless of the value set.
     * @param {number} value
     */
    yZoomIn: number;
    /**
     * Command a zoom reset on the Y axis. Command will be executed
     * regardless of the value set.
     * @param {number} value
     */
    yZoomReset: number;
    /**
     * Set the data update rate of the connection.  This is a maximum update
     * rate and may be approximated.  Setting the value to less than or equal
     * to zero disables this feature (i.e., lets the service push as quickly
     * as the socket and server will allow).
     * @param {number} pps - The maximum number of packets per second to receive.
     */
    packetsPerSecond: number;
    /**
     * Statistic indicating how long it took to deserialize the packet.
     * @return {number} The time required to deserialize the BulkioPacket
     */
    readonly deserializeTime: number;
    /**
     * The number of data words in the most recent packet.
     * @return {number}
     */
    readonly packetLength: number;
    /**
     * The frame size of the most recent packet.
     *      0 - One dimensional data (no frames)
     *     >0 - Two dimensional data
     * @return {number}
     */
    readonly packetSubsize: number;
    /**
     * The complex flag for the most recent packet.
     *     0 - Scalar data
     *     1 - Complex data
     * @return {number}
     */
    readonly packetMode: number;
    /**
     * Release the port's underlying socket service.
     */
    release(): void;
    /**
     * Constructor
     * @param url The REST URL for the port
     * @param rp the REST Python service
     */
    constructor(url: string, rp: RestPythonService);
}
