import { Observable } from 'rxjs';
import { IRestPythonConfig } from './rest-python-config';
/**
 * The REST Python (URL) Service provides generation of the URL end points of the
 * REST Python server.  Aided by dependency injection between services, this service
 * builds URL structures so that a Device Manager can infer its Domain's end point,
 * a Device can infer the Device Manager's end point, and so on.
 */
export declare class RestPythonService {
    /** REST Python host address */
    private _host;
    /** REST Python host port */
    private _port;
    /** REST Python API URL (top-level endpoint) */
    private _apiUrl;
    /** Subject for indicating if the REST configuration changed at runtime */
    private _changed;
    /** Base URL of the REST Python Service */
    private readonly baseUrl;
    /**
     * Be notified when the REST Python Service's URL changes in any way.
     */
    readonly changed$: Observable<void>;
    /** The configured host address for the REST-Python server */
    readonly host: string;
    /** The configured port for the REST-Python server */
    readonly port: number;
    /** The configured API URL for the REST-Python server */
    readonly apiUrl: string;
    /**
     * Constructor
     * @param config The REST Python Configuration
     */
    constructor(config: IRestPythonConfig);
    /**
     * Reconfigure the REST-Python Service to a new service address
     */
    setConfiguration(config: IRestPythonConfig): void;
    /** URL for the REDHAWK interface */
    redhawkUrl(): string;
    /** URL for the Event Channels listing */
    eventChannelsUrl(): string;
    /** URL for the/a Domain's interface */
    domainUrl(parentUrl: string, domainId?: string): string;
    /** URL for a FIle System interface */
    fileSystemUrl(parentUrl: string, path?: string): string;
    /** URL for a Device Manager listing or a specific instance */
    deviceManagerUrl(parentUrl: string, deviceManagerId?: string): string;
    /** URL for a Device listing or a specific instance */
    deviceUrl(parentUrl: string, deviceId?: string): string;
    /** URL for a Service listing or a specific instance */
    serviceUrl(parentUrl: string, serviceId?: string): string;
    /** URL for a Waveform listing or a specific instance */
    waveformUrl(parentUrl: string, waveformId?: string): string;
    /** URL for a Component listing or a specific instance */
    componentUrl(parentUrl: string, componentId?: string): string;
    /** URL for the properties listing on an interface */
    propertyUrl(parentUrl: string): string;
    /** URL for a Port listing or a specific instance */
    portUrl(parentUrl: string, portId?: string): string;
    /** URL for a port's BULKIO WebSocket interface (if applicable) */
    bulkioSocketUrl(portUrl: string): string;
    /** URL of the REDHAWK (Domain) Listener WebSocket (i.e., Domains coming and going) */
    redhawkSocketUrl(): string;
    /** URL for subscribing to Event Channels (WebSocket) */
    eventSocketUrl(): string;
    /**
     * Returns a websocket URL from the provided URL and path
     * @param parentUrl The parent (service) URL
     * @param [subPath] A sub-path to extend on the URL
     */
    private baseWebsocketUrl;
    /**
     * Creates a URL from the parent's and some new end point details.
     * @param parentUrl The parent (service's) URL
     * @param [subPath] A sub-path extending off the parent's URL
     * @param [target] A REST end point combining the above URL elements.
     */
    private baseRestUrl;
}
