import { InjectionToken } from '@angular/core';
import { Observable } from 'rxjs';
import { BulkioPacket } from '../../models/index';
export declare let BULKIO_SOCKET_URL: InjectionToken<string>;
/**
 * The BULKIO Listener Service provides access to BULKIO sockets including control
 * interfaces that allow additional server-side processing to lighten the network
 * and UI load (for plotting data, etc.).
 */
export declare class BulkioListenerService {
    /** The URL of the bulkio websocket */
    private _url;
    /** The most recent connection ID */
    private _connectionId;
    /** Packet relay from the socket */
    private packet;
    /** Socket Interface */
    private socketInterface;
    /** Socket subscription for managing the interface connection */
    private socketSubscription;
    /** The amount of time deserializing a packet took (diagnostics. */
    private _deserializeTime;
    /** Length of the packet */
    private _packetLength;
    /** Packet's subsize */
    private _packetSubsize;
    /** Mode of the packet */
    private _packetMode;
    /** Set the URL.  If connected, this will disconnect and reconnect */
    /** Get the current URL */
    url: string;
    /**
     * Subscribe to receive the bulkio packets.
     * @member {Observable<BulkioPacket>}
     */
    readonly packet$: Observable<BulkioPacket>;
    /**
     * The amount of time it took to deserialize the most recent packet.
     * @member {number}
     */
    readonly deserializeTime: number;
    /**
     * The number of data words in the most recent packet.
     * @member {number}
     */
    readonly packetLength: number;
    /**
     * The frame size of the most recent packet.
     *      0 - One dimensional data (no frames)
     *     >0 - Two dimensional data
     * @member {number}
     */
    readonly packetSubsize: number;
    /**
     * The complex flag for the most recent packet.
     *     0 - Scalar data
     *     1 - Complex data
     * @member {number}
     */
    readonly packetMode: number;
    /**
     * Set the max number of samples for the X axis (causes inter-sample
     * averaging).  The REST Python server will try to adjust to near this limit
     * based on the data size. Setting the width to less than or equal to 0 will
     * disable this feature.
     * @param {number} value
     */
    xMax: number;
    /**
     * Set the beginning index of the zoom region for the X axis. The index is
     * inclusive and based on data available at the UI (the server will adjust
     * the index for the actual packet size). The zoom will not be enabled until
     * the zoom level is set.
     * @param {number} value
     */
    xBegin: number;
    /**
     * Set the ending index of the zoom region for the X axis. The index is
     * inclusive and based on data available at the UI (the server will adjust
     * the index for the actual packet size). The zoom will not be enabled until
     * the zoom level is set.
     * @param {number} value
     */
    xEnd: number;
    /**
     * Command a zoom in on the X axis. Command will be executed
     * regardless of the value set.
     * @param {number} value
     */
    xZoomIn: number;
    /**
     * Command a zoom reset on the X axis. Command will be executed
     * regardless of the value set.
     * @param {number} value
     */
    xZoomReset: number;
    /**
     * Set the max number of samples for the Y axis (causes inter-sample
     * averaging).  The REST Python server will try to adjust to near this limit
     * based on the data size. Setting the width to less than or equal to 0 will
     * disable this feature.
     * @param {number} value
     */
    yMax: number;
    /**
     * Set the beginning index of the zoom region for the Y axis. The index is
     * inclusive and based on data available at the UI (the server will adjust
     * the index for the actual packet size). The zoom will not be enabled until
     * the zoom level is set.
     * @param {number} value
     */
    yBegin: number;
    /**
     * Set the ending index of the zoom region for the Y axis. The index is
     * inclusive and based on data available at the UI (the server will adjust
     * the index for the actual packet size). The zoom will not be enabled until
     * the zoom level is set.
     * @param {number} value
     */
    yEnd: number;
    /**
     * Command a zoom in on the Y axis. Command will be executed
     * regardless of the value set.
     * @param {number} value
     */
    yZoomIn: number;
    /**
     * Command a zoom reset on the Y axis. Command will be executed
     * regardless of the value set.
     * @param {number} value
     */
    yZoomReset: number;
    /**
     * Set the (maximum) socket data rate (packets per second)
     * @param {number} pps - The (maximum) number of packets per second to receive (< 0 to disable)
     */
    packetsPerSecond: number;
    /**
     * Returns whether the service is already connected.
     * @return {boolean} True: WebSocket is connected, False: it is not.
     */
    readonly connected: boolean;
    /**
     * Returns whether anything is actually subscribed to receive packets.
     * @return {boolean} True: Subscribers are present, False: No subscribers.
     */
    readonly active: boolean;
    /**
     * Connect to the BULKIO socket at the url.
     * @param [connectionId] The connection ID to issue (also, the allocation ID if connecting to
     *        an allocated multi-port FEI Device).
     */
    connect(connectionId?: string): void;
    /**
     * Disconnect from the BULKIO socket.
     */
    disconnect(): void;
    /**
     * Constructor
     * @param {string} url - The base URL (ws:// or wss://) of the port
     */
    constructor(url: string);
}
